@@ -16,11 +16,146 @@
 */
 mod tests {
     use crate::*;
+    //const A: &str = "01\t23\n45\t67\n89";
+    const A: &str = "	Header starts here
+	Comments starts with tab char
+width 22	Count of symbols in column
+height 14	Cpunt of rows in frames
+loop true
+colors full	Colors are specified for both text and background
+delay 200
+@ In header comments also may starts with @ char
+
+
+
+	There
+	is
+	one
+	ore
+	more
+	empty
+	lines
+	between
+	header
+	and
+	body
+
+
+
+	Body starts here
+	First frame
+LU]Pk&3):F*k[]qbd;$0Bp77777777777777777777770000000000000000000000	First row
+}YZ7Ik;=a^KF(0CxvF5AU+77777777777777777777770000000000000000000000	Second row
+uPJZ]RJ3]^xsyJ~-;2~.dW777777cccccc77777777770000003333330000000000	Third row
+pj&<rH.vFN6odJ5c-l~CRx777777cccccc77777777770000003333330000000000
+A!ht(UB@(jNDl.67+n)?,N7777777777cc77cccccc770000000000330033333300
+v6,gTX64AWFW>%>IdAxSgW7777777777cc77cccccc770000000000330033333300
+}[FiPQzkcMdG@K!<@dvC-$777777cccccc77cc77cc770000003333330033003300
+C:DT+Odt-P(0pu%r}vlr#H777777cccccc77cc77cc770000003333330033003300
+wAD)<iMp>L}yh}Y+}-r$BN7777777777cc77cccccc770000000000330033333300
+@,ekE:w[Xt8sCmxxFj9EHN7777777777cc77cccccc770000000000330033333300
+rX7=W;uEZii2*xosZuDRBg77cc77cccccc77cc77cc770033003333330033003300
+vHtkD411dJ>P~3=kkB4wU^77cc77cccccc77cc77cc770033003333330033003300
+,6oFB+gD3f_%gJua{50=HD77777777777777777777770000000000000000000000
+rq5?T0lL06Vg-[0G:,sum)77777777777777777777770000000000000000000000
+
+	Second frame
+lH<^&?@^Hbt^3v5]7gx9<o	First column in a first row
+7777777777777777777777	Second column in a first row
+0000000000000000000000	Third column in a first row
+hoB<mg>DGKGfM3woWh4%EC77777777777777777777770000000000000000000000
+Js%6!JG[m,C8PVsrG7_ESx777777cccccc77777777770000003333330000000000
+dCX<E6]xxP~Hk(([D*dGU?777777cccccc77777777770000003333330000000000
+~!gdx`w[f0z)xKbnj{rAWS7777777777cc77cccccc770000000000330033333300
+5V=hf%`00gl2-YlT;L*&U`7777777777cc77cccccc770000000000330033333300
+qk[3_hDMUNNIn}Y`F>lh@o777777cccccc77cc77cc770000003333330033003300
+HsHD0=38OO.#iCA&~U[{kT777777cccccc77cc77cc77
+0000003333330033003300v#x@h.OzV,zLI6#5&kv4T-777777777	You can add line breaks anywhere in the body.
+7cc77cccccc770000000000330033333300			Any way they, like comments, are ignored by the parser.
+#t:Gic$*w-i;P<O!fIWdC,7777777777cc77cccccc770000000000330033333300
+zs{lk^a3Ty8SbYgLGe7Pdt77cc77cccccc77cc77cc770033003333330033003300
+i#%5(w~u9+cdlOdO!&Ms}677cc77cccccc77cc77cc770033003333330033003300
+Ou=JC8Zn.T;pq98cx)ov>~77777777777777777777770000000000000000000000
+aNvuQi.U6%7-Kf,uk{FG[J77777777777777777777770000000000000000000000
+
+	Third frame
+Jk%bTX:]aZ,D?jkB0?*I*O77777777777777777777770000000000000000000000
+r~&Em{~S%FVCv._]xdt5.,77777777777777777777770000000000000000000000
+OEr=o[s:ocqCa;,h2a-d:q777777cccccc77777777770000003333330000000000
+U6]~]fX>~%T%(RAa$p`~n!777777cccccc77777777770000003333330000000000
+YRq`hu=gRKg.!k>82v#[^D7777777777cc77cccccc770000000000330033333300
+C#F7Nq3U3!yopFgBSRoUPB7777777777cc77cccccc770000000000330033333300
+)p_U9Fhxi]W1IE)=s$>dh^777777cccccc77cc77cc770000003333330033003300
+8uhRPgAy2}uioTM5Rw@>*5777777cccccc77cc77cc770000003333330033003300
+xgq#T=V5d}8WaQU+kez]>X7777777777cc77cccccc770000000000330033333300
+ed`pS6%DK9N% iQo7-[gDO7777777777cc77cccccc770000000000330033333300
+[Z:jGUY%L&$74[@Q8;Km~E77cc77cccccc77cc77cc770033003333330033003300
+gQ{ikr-5fyM<{ny6=]r4U$77cc77cccccc77cc77cc770033003333330033003300
+iVG.vOv5uWkulYY#GT[&Tm77777777777777777777770000000000000000000000
+U0DC_D-@ml4[7sP7&)C9Q>77777777777777777777770000000000000000000000";
+    //const B: &str = "014589";
+    const B: &str = "width 22
+height 14
+loop true
+colors full
+delay 200
+@ In header comments also may starts with @ char
+
+
+
+
+
+
+LU]Pk&3):F*k[]qbd;$0Bp77777777777777777777770000000000000000000000
+}YZ7Ik;=a^KF(0CxvF5AU+77777777777777777777770000000000000000000000
+uPJZ]RJ3]^xsyJ~-;2~.dW777777cccccc77777777770000003333330000000000
+pj&<rH.vFN6odJ5c-l~CRx777777cccccc77777777770000003333330000000000
+A!ht(UB@(jNDl.67+n)?,N7777777777cc77cccccc770000000000330033333300
+v6,gTX64AWFW>%>IdAxSgW7777777777cc77cccccc770000000000330033333300
+}[FiPQzkcMdG@K!<@dvC-$777777cccccc77cc77cc770000003333330033003300
+C:DT+Odt-P(0pu%r}vlr#H777777cccccc77cc77cc770000003333330033003300
+wAD)<iMp>L}yh}Y+}-r$BN7777777777cc77cccccc770000000000330033333300
+@,ekE:w[Xt8sCmxxFj9EHN7777777777cc77cccccc770000000000330033333300
+rX7=W;uEZii2*xosZuDRBg77cc77cccccc77cc77cc770033003333330033003300
+vHtkD411dJ>P~3=kkB4wU^77cc77cccccc77cc77cc770033003333330033003300
+,6oFB+gD3f_%gJua{50=HD77777777777777777777770000000000000000000000
+rq5?T0lL06Vg-[0G:,sum)77777777777777777777770000000000000000000000
+
+lH<^&?@^Hbt^3v5]7gx9<o
+7777777777777777777777
+0000000000000000000000
+hoB<mg>DGKGfM3woWh4%EC77777777777777777777770000000000000000000000
+Js%6!JG[m,C8PVsrG7_ESx777777cccccc77777777770000003333330000000000
+dCX<E6]xxP~Hk(([D*dGU?777777cccccc77777777770000003333330000000000
+~!gdx`w[f0z)xKbnj{rAWS7777777777cc77cccccc770000000000330033333300
+5V=hf%`00gl2-YlT;L*&U`7777777777cc77cccccc770000000000330033333300
+qk[3_hDMUNNIn}Y`F>lh@o777777cccccc77cc77cc770000003333330033003300
+HsHD0=38OO.#iCA&~U[{kT777777cccccc77cc77cc77
+0000003333330033003300v#x@h.OzV,zLI6#5&kv4T-777777777
+7cc77cccccc770000000000330033333300
+#t:Gic$*w-i;P<O!fIWdC,7777777777cc77cccccc770000000000330033333300
+zs{lk^a3Ty8SbYgLGe7Pdt77cc77cccccc77cc77cc770033003333330033003300
+i#%5(w~u9+cdlOdO!&Ms}677cc77cccccc77cc77cc770033003333330033003300
+Ou=JC8Zn.T;pq98cx)ov>~77777777777777777777770000000000000000000000
+aNvuQi.U6%7-Kf,uk{FG[J77777777777777777777770000000000000000000000
+
+Jk%bTX:]aZ,D?jkB0?*I*O77777777777777777777770000000000000000000000
+r~&Em{~S%FVCv._]xdt5.,77777777777777777777770000000000000000000000
+OEr=o[s:ocqCa;,h2a-d:q777777cccccc77777777770000003333330000000000
+U6]~]fX>~%T%(RAa$p`~n!777777cccccc77777777770000003333330000000000
+YRq`hu=gRKg.!k>82v#[^D7777777777cc77cccccc770000000000330033333300
+C#F7Nq3U3!yopFgBSRoUPB7777777777cc77cccccc770000000000330033333300
+)p_U9Fhxi]W1IE)=s$>dh^777777cccccc77cc77cc770000003333330033003300
+8uhRPgAy2}uioTM5Rw@>*5777777cccccc77cc77cc770000003333330033003300
+xgq#T=V5d}8WaQU+kez]>X7777777777cc77cccccc770000000000330033333300
+ed`pS6%DK9N% iQo7-[gDO7777777777cc77cccccc770000000000330033333300
+[Z:jGUY%L&$74[@Q8;Km~E77cc77cccccc77cc77cc770033003333330033003300
+gQ{ikr-5fyM<{ny6=]r4U$77cc77cccccc77cc77cc770033003333330033003300
+iVG.vOv5uWkulYY#GT[&Tm77777777777777777777770000000000000000000000
+U0DC_D-@ml4[7sP7&)C9Q>77777777777777777777770000000000000000000000";
     #[test]
     fn test_escape_comments(){
-        let a = "01\t23\n45\t67\n89".to_string();
-        let b = "014589".to_string();
-        assert_eq!(escape_comments(&a), b);
+        assert_eq!(escape_comments(A), B.to_string());
     }
 }
 
